==> haskell-cryptohash-cryptoapi-0.1.4-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-6PeCJKRzcfn9OCe9wgblGE
key: cryptohash-cryptoapi-0.1.4-6PeCJKRzcfn9OCe9wgblGE
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: f12634acefd7106444eb6298e5ecbc59
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-6PeCJKRzcfn9OCe9wgblGE
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=77866f631eefa2be10fa7c88fcec53a0
             crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU=1a6e7f0af01b596195406422512f7c1f
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=8f78e013407135fc5016173a57c7eb1b
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptohash-cryptoapi
version: 0.1.4
id: cryptohash-cryptoapi-0.1.4-lNi3AaCO2YJfrttSAwyhZ
key: cryptohash-cryptoapi-0.1.4-lNi3AaCO2YJfrttSAwyhZ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis: Crypto-api interfaces for cryptohash
description:
    Crypto-api interfaces for cryptohash
category: Cryptography
abi: 1b7a23de0cb54a3f018e1ddc0121e8b5
exposed: True
exposed-modules:
    Crypto.Hash.CryptoAPI
import-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cryptohash-cryptoapi-0.1.4
hs-libraries: HScryptohash-cryptoapi-0.1.4-lNi3AaCO2YJfrttSAwyhZ
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
    cryptonite-0.25-90uxV0bWEYmfC6QouwM7s
    memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=77866f631eefa2be10fa7c88fcec53a0
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=80ac8ea08d0f7b8153da8b322f955d96
             cryptonite-0.25-90uxV0bWEYmfC6QouwM7s=ab6703e009204c8918b02064ccbf4d84
             memory-0.14.16-Hs1NDoAVjuC3IQmOlFTQpi=463ac0313409de6dd760baee29e5aba2
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
haddock-interfaces: /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock
haddock-html: /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
